@@ -17,8 +17,7 @@ describe 'designate::logging' do
       :publish_errors => true,
       :default_log_levels => { 
         'amqp' => 'WARN', 'amqplib' => 'WARN', 'boto' => 'WARN',
-        'qpid' => 'WARN', 'sqlalchemy' => 'WARN', 'suds' => 'INFO',
-        'iso8601' => 'WARN',
+        'sqlalchemy' => 'WARN', 'suds' => 'INFO', 'iso8601' => 'WARN',
         'requests.packages.urllib3.connectionpool' => 'WARN' },
      :fatal_deprecations => true,
      :instance_format => '[instance: %(uuid)s] ',
@@ -28,7 +27,6 @@ describe 'designate::logging' do
      :use_stderr => false,
      :log_facility => 'LOG_FOO',
      :log_dir => '/var/log',
-     :verbose => true,
      :debug => true,
     }
   end
@@ -57,10 +55,11 @@ describe 'designate::logging' do
 
   shared_examples 'basic default logging settings' do
     it 'configures designate logging settins with default values' do
-      is_expected.to contain_designate_config('DEFAULT/use_syslog').with(:value => 'false')
-      is_expected.to contain_designate_config('DEFAULT/use_stderr').with(:value => 'true')
-      is_expected.to contain_designate_config('DEFAULT/verbose').with(:value => 'false')
-      is_expected.to contain_designate_config('DEFAULT/debug').with(:value => 'false')
+      is_expected.to contain_designate_config('DEFAULT/use_syslog').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_designate_config('DEFAULT/use_stderr').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_designate_config('DEFAULT/syslog_log_facility').with(:value => '<SERVICE DEFAULT>')
+      is_expected.to contain_designate_config('DEFAULT/log_dir').with(:value => '/var/log/designate')
+      is_expected.to contain_designate_config('DEFAULT/debug').with(:value => '<SERVICE DEFAULT>')
     end
   end
 
@@ -70,7 +69,6 @@ describe 'designate::logging' do
       is_expected.to contain_designate_config('DEFAULT/use_stderr').with(:value => 'false')
       is_expected.to contain_designate_config('DEFAULT/syslog_log_facility').with(:value => 'LOG_FOO')
       is_expected.to contain_designate_config('DEFAULT/log_dir').with(:value => '/var/log')
-      is_expected.to contain_designate_config('DEFAULT/verbose').with(:value => 'true')
       is_expected.to contain_designate_config('DEFAULT/debug').with(:value => 'true')
     end
   end
@@ -95,7 +93,7 @@ describe 'designate::logging' do
         true)
 
       is_expected.to contain_designate_config('DEFAULT/default_log_levels').with_value(
-        'amqp=WARN,amqplib=WARN,boto=WARN,iso8601=WARN,qpid=WARN,requests.packages.urllib3.connectionpool=WARN,sqlalchemy=WARN,suds=INFO')
+        'amqp=WARN,amqplib=WARN,boto=WARN,iso8601=WARN,requests.packages.urllib3.connectionpool=WARN,sqlalchemy=WARN,suds=INFO')
 
       is_expected.to contain_designate_config('DEFAULT/fatal_deprecations').with_value(
         true)
@@ -119,7 +117,7 @@ describe 'designate::logging' do
      :default_log_levels, :fatal_deprecations,
      :instance_format, :instance_uuid_format,
      :log_date_format, ].each { |param|
-        it { is_expected.to contain_designate_config("DEFAULT/#{param}").with_ensure('absent') }
+        it { is_expected.to contain_designate_config("DEFAULT/#{param}").with(:value => '<SERVICE DEFAULT>') }
       }
   end
 
